#ifndef BINDBUTTON_H
#define BINDBUTTON_H

#include <QMaemo5ValueButton>

#include <QKeyEvent>
#include <QButtonGroup>

#include <QDBusConnection>

#include <QX11Info>
#include <X11/Xlib.h>
#include <X11/Xatom.h>

class BindButton : public QMaemo5ValueButton
{
    Q_OBJECT

public:
    BindButton(QString text, int code, QWidget *parent);

    int keyCode();

private:
    int code;

    void setKeyCode(int code);
    void grabZoomKeys(bool grab);

    void keyPressEvent(QKeyEvent *e);
    void contextMenuEvent(QContextMenuEvent*);

private slots:
    void onToggled(bool checked);
    void onCamFocusPressed();
};

#endif // BINDBUTTON_H
